#!/usr/bin/env Rscript
## ---------------------------
##
## Script name: calculate gridded SPEI
##
## Purpose of script: Calculate gridded SPEI
## Author: Daniela Lührsen & Emily Ball
## Date Created: 2025-03-07
## Email: daniela.luhrsen@bsc.es
##
## ---------------------------

## load up the packages
packages <- c("startR", "s2dv", "CSTools", "multiApply", "ClimProjDiags",
              "SPEI", "zoo", "TLMoments", "lmomco", "lmom", "lubridate", "dplyr",
              "raster", "sf")
install.packages(setdiff(packages, rownames(installed.packages())))
lapply(packages, require, character.only = TRUE)

## load local functions
source("support_functions/load_data.R")
source("support_functions/save_SPEI.R")
source("support_functions/convert_raster.R")

## ---------------------------
# select parameters:
region <- "europe"
accum <- c(6, 12) # c(1, 3, 6, 12)
calculate_spi <- FALSE
calculate_spei <- TRUE
dataset <- "era5land"
start_year <- 1980
end_year <- 2024
start_month <- 1
end_month <- 12
ref_period  <- c(1981, 2010)

# flags to load input variables, calculate SPEI and convert to raster
load_data <- TRUE
save_spei <- TRUE
convert_spei_raster <- TRUE
pop_raster <- FALSE

# set coordinates
lats_min <- 25
lats_max <- 75
lons_min <- -34
lons_max <- 45

vars <- c("spi"[calculate_spi], "spei"[calculate_spei])


if (load_data == TRUE) {
  # obtain dates for startR call:
  for (mm in start_month:end_month){
    if (mm == start_month) {
      dates <- as.Date(paste0(start_year:end_year, "-", start_month, "-1"))
    } else {
      dates <- append(dates, as.Date(paste0(start_year:end_year, "-", mm, "-1")))
    }
  }
  dates <- dates[order(dates)]
  dates <- array(substr(gsub("-", "", as.character(dates)), 1, 6),
                 dim = c(time = (end_month - start_month + 1),
                         syear = (end_year - start_year + 1)))

  load_data_era5land(dates, region,
                   lats_min, lats_max,
                   lons_min, lons_max,
                   calculate_spei)
}

# SPEI ----
if (save_spei == TRUE) {
  for (i in accum) {
    save_SPEI_era5land(region, i,
                       calculate_spi, calculate_spei,
                       ref_period)
  }
}

if (convert_spei_raster == TRUE) {
  # convert to raster -------------------------------------------------------
  for (i in accum) {
    convert_to_raster_era5land(i, vars, region)
  }
}

if (pop_raster == TRUE) {
  # create population raster -----------------------------------------------
  out <- convert_to_raster_population_era5land(region, vars, accum)
}
