#!/usr/bin/env Rscript
## ---------------------------
##
## Script name: save components of SPEI
##
## Purpose of script: save PET and precipitation
## Author: Daniela Lührsen & Emily Ball
## Date Created: 2025-03-07
## Email: daniela.luhrsen@bsc.es
##
## ---------------------------

# load packages
packages <- c("sf", "lubridate", "zoo", "raster", "dplyr", "SPEI",
              "multiApply", "tidyr", "ggplot2", "CSIndicators", "CSTools")
lapply(packages, require, character.only = TRUE)

## load local functions
source("support_functions/load_data.R")
source("support_functions/save_SPEI.R")
source("support_functions/convert_raster.R")

region <- "europe"

# calculate PET: load climate
tasmax <- readRDS("data/europe_tasmax.rds")
tasmin <- readRDS("data/europe_tasmin.rds")
data <- list('tmax' = tasmax, 'tmin' = tasmin)
pet <- CST_PeriodPET(data = data, pet_method = "hargreaves")
saveRDS(pet, "data/europe_PET.rds")
rm(tasmax, tasmin, data, pet)


# convert to raster
convert_to_raster_input_variables("prlr", region)
convert_to_raster_input_variables("PET", region)