#!/usr/bin/env Rscript
## ---------------------------
##
## Script name: mask indicators by land
##
## Purpose of script: mask indicators by land
## Author: Daniela Lührsen & Emily Ball
## Date Created: 2025-03-07
## Email: daniela.luhrsen@bsc.es
##
## ---------------------------

# load packages
packages <- c("sf", "lubridate", "zoo", "raster", "dplyr",
              "tidyr", "ggplot2", "terra")
lapply(packages, require, character.only = TRUE)

region <- "europe"

rasterOptions(tmpdir = "/scratch/eball")
terraOptions( tmpdir = "/scratch/eball")

# load shapefile
adm1 <- sf::st_read("../01_shapefiles/data/outputs/europe.shp")

adm1_proj <- st_transform(adm1, crs = 4326)
adm1_vect <- vect(adm1_proj)
rm(adm1_proj, adm1)

for (var in c("spei_12")) {#, "spei_6", "prlr", "PET")) {
  data_stack <- readRDS(paste0("data/europe_", var, "_stack.rds"))
  data_stack_rast <- rast(data_stack)
  rm(data_stack)
  data_masked <- NULL
  for (i in 1:nlyr(data_stack_rast)) {
    data_masked[[i]] <- mask(crop(data_stack_rast[[i]], adm1_vect), adm1_vect)
    print(i)
  }
  saveRDS(rast(data_masked), paste0("data/temp/europe-masked_", var, ".rds"))
  rm(data_masked, data_stack_rast)
}