load_data_era5land <- function(dates, region,
                               lats_min, lats_max,
                               lons_min, lons_max,
                               calculate_spei) {
  
  # precipitation ----
  # obtain path for startR call:
  path_dataset <- "/esarchive/recon/ecmwf/era5land/monthly_mean/$var$_f1h/$var$_$sdate$.nc"
  
  # startR call:
  data_prlr <- startR::Start(dat = path_dataset,
                             var = "prlr",
                             sdate = dates,
                             split_multiselected_dims = TRUE,
                             latitude = startR::values(list(lats_min, lats_max)),
                             latitude_reorder = startR::Sort(decreasing = TRUE),
                             longitude = startR::values(list(lons_min, lons_max)),
                             longitude_reorder = startR::CircularSort(-180, 180),
                             synonims = list(latitude = c("lat", "latitude"),
                                             longitude = c("lon", "longitude")),
                             return_vars = list(latitude = "dat",
                                                longitude = "dat",
                                                time = c("sdate")),
                             retrieve = TRUE)
  data_prlr <- data_prlr * 3600 * 24 * 30.44 * 1000
  attr(data_prlr, "Variables")$common$prlr$units <- "mm"
  data_prlr <- CSTools::as.s2dv_cube(data_prlr)
  if (!("ensemble" %in% names(data_prlr$data))) {
    data_prlr$data <- s2dv::InsertDim(data_prlr$data, pos =  5, len = 1, name = "ensemble")
  }
  saveRDS(data_prlr, paste0("data/", region, "_prlr.rds"))
  
  # tasmax ----
  if (calculate_spei) {
    path_dataset <- "/esarchive/recon/ecmwf/era5land/monthly_mean/$var$_f24h/$var$_$sdate$.nc"
  
    # startR call:
    data_tasmax <- startR::Start(dat = path_dataset,
                                 var = "tasmax",
                                 sdate = dates,
                                 split_multiselected_dims = TRUE,
                                 latitude = startR::values(list(lats_min, lats_max)),
                                 latitude_reorder = startR::Sort(decreasing = TRUE),
                                 longitude = startR::values(list(lons_min, lons_max)),
                                 longitude_reorder = startR::CircularSort(-180, 180),
                                 synonims = list(latitude = c("lat", "latitude"),
                                                 longitude = c("lon", "longitude")),
                                 return_vars = list(latitude = "dat",
                                                    longitude = "dat",
                                                    time = c("sdate")),
                                 retrieve = TRUE)
    data_tasmax <- data_tasmax - 273.15
    attr(data_tasmax, "Variables")$common$tasmax$units <- "C"
    data_tasmax <- CSTools::as.s2dv_cube(data_tasmax)
    if (!("ensemble" %in% names(data_tasmax$data))) {
      data_tasmax$data <- s2dv::InsertDim(data_tasmax$data, pos =  5,
                                          len = 1, name = "ensemble")
    }
    saveRDS(data_tasmax, paste0("data/", region, "_tasmax.rds"))
  }
  
  # tasmin ----
  if (calculate_spei) {
    path_dataset <- "/esarchive/recon/ecmwf/era5land/monthly_mean/$var$_f24h/$var$_$sdate$.nc"
  
    # startR call:
    data_tasmin <- startR::Start(dat = path_dataset,
                                 var = "tasmin",
                                 sdate = dates,
                                 split_multiselected_dims = TRUE,
                                 latitude = startR::values(list(lats_min, lats_max)),
                                 latitude_reorder = startR::Sort(decreasing = TRUE),
                                 longitude = startR::values(list(lons_min, lons_max)),
                                 longitude_reorder = startR::CircularSort(-180, 180),
                                 synonims = list(latitude = c("lat", "latitude"),
                                                 longitude = c("lon", "longitude")),
                                 return_vars = list(latitude = "dat",
                                                    longitude = "dat",
                                                    time = c("sdate")),
                                 retrieve = TRUE)
    data_tasmin <- data_tasmin - 273.15
    attr(data_tasmin, "Variables")$common$tasmin$units <- "C"
    data_tasmin <- CSTools::as.s2dv_cube(data_tasmin)
    if (!("ensemble" %in% names(data_tasmin$data))) {
      data_tasmin$data <- s2dv::InsertDim(data_tasmin$data, pos =  5,
                                          len = 1, name = "ensemble")
    }
    saveRDS(data_tasmin, paste0("data/", region, "_tasmin.rds"))
  }
}